@@ -9,5 +9,12 @@
 
 
 marking <- function(PN) {
+
+	lifecycle::deprecate_warn(
+		when = "0.3.0",
+		what = "marking()",
+		with = "initial_marking()")
+
+
 	return(PN$marking)
 }
