@@ -7,9 +7,12 @@
 #'
 #' @export parsel_trace
 
-
-
 parsel_trace <- function(PN, trace) {
+
+	lifecycle::deprecate_warn(
+		when = "0.3.0",
+		what = "enabled()")
+
 	for(i in 1:length(trace)) {
 		if(trace[i] %in% enabled(PN)$id){
 			PN <- execute(PN, trace[i])
